@@ -25,7 +25,7 @@
 %% GPL v3.
 %%
 %% FIXME: once we no longer try to support Octave 3.6, drop most of
-%% this and call "__run_test_suite(@{'@@sym', '@@symfun'@}, @{@})"
+%% this and call "__run_test_suite__(@{'@@sym', '@@symfun'@}, @{@})"
 %% instead.  See https://savannah.gnu.org/bugs/?41215
 %%
 %% @end defun
@@ -56,7 +56,7 @@ function anyfail = octsympy_tests ()
   try
     page_screen_output (false);
     warning ("off", "Octave:deprecated-function");
-    fid = fopen ("octsympy_tests.log", "wt");
+    fid = fopen (fullfile(mycwd, "octsympy_tests.log"), "wt");
     if (fid < 0)
       error ("could not open octsympy_tests.log for writing");
     endif
