@@ -1,5 +1,5 @@
 %% Copyright (C) 2003 Willem J. Atsma
-%% Copyright (C) 2014, 2015 Colin B. Macdonald
+%% Copyright (C) 2014-2016 Colin B. Macdonald
 %%
 %% This program is free software; you can redistribute it and/or
 %% modify it under the terms of the GNU General Public
@@ -18,11 +18,11 @@
 
 %% -*- texinfo -*-
 %% @documentencoding UTF-8
-%% @deftypefn  {Function File} {@var{p} =} poly2sym (@var{c})
-%% @deftypefnx {Function File} {@var{p} =} poly2sym (@var{c}, @var{x})
+%% @defun  poly2sym (@var{c})
+%% @defunx poly2sym (@var{c}, @var{x})
 %% Create a symbolic polynomial expression from coefficients.
 %%
-%% If @var{x} is not specified, the free variable is set to @code{x}. @var{c}
+%% If @var{x} is not specified, the free variable is set to @code{sym('x')}. @var{c}
 %% may be a vector of doubles or syms. It can also be a cell array vector.
 %% @var{x} may be a symbolic expression or something that converts to one.
 %% The coefficients correspond to decreasing exponent of the free variable.
@@ -33,23 +33,25 @@
 %% x = sym ('x');
 %% y = sym ('y');
 %% poly2sym ([2 5])
-%%    @result{} (sym) 2⋅x + 5
+%%   @result{} (sym) 2⋅x + 5
 %% poly2sym (@{2*y 5 -3@}, x)
-%%    @result{} (sym)
+%%   @result{} (sym)
 %%          2
 %%       2⋅x ⋅y + 5⋅x - 3
 %% @end group
 %% @end example
 %%
-%% @seealso{sym2poly, polyval, roots}
-%% @end deftypefn
+%% @seealso{@@sym/sym2poly, polyval, roots}
+%% @end defun
 
 function p = poly2sym(c,x)
 
   if (nargin == 1)
     x = sym('x');
-  else
+  elseif (nargin == 2)
     x = sym(x);
+  else
+    print_usage ();
   end
 
   N = length(c);
