@@ -1,4 +1,5 @@
 %% Copyright (C) 2014-2016 Colin B. Macdonald
+%% Copyright (C) 2017 Mike Miller
 %%
 %% This file is part of OctSymPy.
 %%
@@ -17,14 +18,14 @@
 %% If not, see <http://www.gnu.org/licenses/>.
 
 %% -*- texinfo -*-
-%% @deftypefn  {Function File}  {[@var{A}, @var{db}] =} python_ipc_driver (@dots{})
+%% @deftypefun {[@var{A}, @var{db}] =} python_ipc_driver (@dots{})
 %% Private function: run Python/SymPy command and return objects.
 %%
 %% @var{A} is the resulting object, which might be an error code.
 %%
 %% @var{db} usually contains diagnostics to help with debugging
 %% or error reporting.
-%% @end deftypefn
+%% @end deftypefun
 
 function [A, db] = python_ipc_driver(what, cmd, varargin)
 
@@ -32,12 +33,10 @@ function [A, db] = python_ipc_driver(what, cmd, varargin)
 
   %% version check
   if exist('OCTAVE_VERSION', 'builtin')
-    if (compare_versions (OCTAVE_VERSION (), '3.6.4', '<'))
+    if (compare_versions (OCTAVE_VERSION (), '4.0.0', '<'))
       fprintf(['\n********************************************************************\n' ...
                'Your Octave version is %s but Octsympy is currently untested on\n' ...
-               'anything before 3.6.4.  For example, persistent variables don''t\n' ...
-               'seem to work properly on 3.2.4.\n\n'], ...
-              OCTAVE_VERSION ())
+               'anything before 4.0.0.\n\n'], OCTAVE_VERSION ())
       warning('Old Octave version detected: probably trouble ahead!')
       fprintf('\n********************************************************************\n\n')
       fflush(stdout);
@@ -53,6 +52,9 @@ function [A, db] = python_ipc_driver(what, cmd, varargin)
   end
 
   switch lower(which_ipc)
+    case 'native'
+      [A, db] = python_ipc_native(what, cmd, varargin{:});
+
     case 'popen2'
       [A, db] = python_ipc_popen2(what, cmd, varargin{:});
 
@@ -72,5 +74,10 @@ function [A, db] = python_ipc_driver(what, cmd, varargin)
       [A, db] = python_ipc_sysoneline(what, cmd, false, varargin{:});
 
     otherwise
-      error('invalid ipc mechanism')
+      if (strcmp (what, 'reset'))
+        A = true;
+        db = [];
+      else
+        error ('invalid ipc mechanism')
+      end
   end
