@@ -1,4 +1,4 @@
-%% Copyright (C) 2014-2017 Colin B. Macdonald
+%% Copyright (C) 2014-2018 Colin B. Macdonald
 %%
 %% This file is part of OctSymPy.
 %%
@@ -181,9 +181,16 @@ function varargout = python_cmd(cmd, varargin)
     end
   elseif (~isempty(A) && ischar(A{1}) && strcmp(A{1}, 'INTERNAL_PYTHON_ERROR'))
     % Here A{3} is the error msg and A{2} is more info about where it happened
-    error (['Python exception: %s\n    occurred %s.\n    Consider filing ' ...
-            'an issue at https://github.com/cbm755/octsympy/issues'], ...
-           A{3}, A{2});
+    if (strfind (A{3}, 'KeyboardInterrupt'))
+      what_to_do = ['Probably something was interrupted by "Ctrl-C".\n' ...
+                    '    Do "sympref reset" and repeat your command.'];
+    else
+      what_to_do = ['Try "sympref reset" and repeat your command?\n' ...
+                    '    (consider filing an issue at ' ...
+                    'https://github.com/cbm755/octsympy/issues)'];
+    end
+    error ('Python exception: %s\n    occurred %s.\n    %s', ...
+           A{3}, A{2}, sprintf (what_to_do))
   end
 
   M = length(A);
